==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/grp_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'grp_common.lang.php');


//HEADER
$lang['hdr_blocked'] = 							"blocked";
$lang['hdr_delete_membership'] = 				"delete membership";
$lang['hdr_delete_membership_confirm'] = 		"confirm";
$lang['hdr_member_library'] = 					"latest published wiki pages";
$lang['hdr_member_blogs'] = 					"latest published blogs";
$lang['hdr_member_subjects'] = 					"latest published subjects";
$lang['hdr_member_comments'] = 					"latest published comments";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_edit_membership'] = 					"edit membership";
$lang['hdr_profile'] =		 					"profile";
$lang['hdr_apply'] = 							"joining this group";
$lang['hdr_group_rules'] = 						"group rules";
$lang['hdr_node_rules'] = 						"node rules";

// SUBMIT
$lang['sub_confirm_delete'] =		 			"CONFIRM DELETION";
$lang['sub_join'] = 							"join";


//A HREF TAGS (links)
$lang['href_blocked_list'] = 					"see blocked user list";


//BODY TEXT
$lang['txt_delete_membership'] = 				"Do you want to delete your membership of this group? You can press 'delete' below to do so. You will be prompted to confirm your request.";
$lang['txt_delete_membership_confirm'] = 		"Please confirm that you want to be deleted pressing 'confirm deletion'. Please note, the contributions you have made to this group will not be deleted.";
$lang['txt_member_profile'] = 					"member profile";
$lang['txt_blocked_help'] = 					"This person is blocked.";
$lang['txt_group_join_date'] = 					"group join date";
$lang['txt_membership_role'] = 					"type";
$lang['txt_profile_create_datetime'] = 			"joined";
$lang['txt_profile_hometown'] = 				"home town";
$lang['txt_profile_join_date'] = 				"community join date";
$lang['txt_profile_session_status'] = 			"status";
$lang['txt_profile_summary'] = 					"summary";
$lang['txt_member_role'] = 						"member role";
$lang['txt_member_status'] = 					"member status";
$lang['txt_membership_number'] = 				"number";
$lang['txt_profile'] = 							"profile";
$lang['txt_registration_type'] = 				"registration type";
$lang['txt_group_title'] =						"title";
$lang['txt_language'] = 						"language";
$lang['txt_start_date'] = 						"start date";
$lang['txt_status'] = 							"group status";
$lang['txt_group_age'] = 						"recommended age";
$lang['txt_group_registration_type'] = 			"registration type";
$lang['txt_no_access_allowed_login'] = 			"Please <a href='index.php'>login</a> or <a href='register.php'>register</a> to apply to join this group.";
$lang['txt_join_notes'] = 						"I agree to the rules";
$lang['txt_group_pending'] = 					"Your group application is pending. The group administrator will Instant message you with the results of your application.";
$lang['txt_group_automatic'] = 					"Welcome to this group. Press the button below to come on in.";
$lang['txt_group_approved'] = 					"Welcome to this group. Press the button below to join. The group administrator will contact you if your application is approved";
$lang['txt_group_unavailable'] = 				"Sorry, this group is unavailable at this time.";
$lang['txt_profile_select_txt'] = 				"select the profile you wish to use in this group";
$lang['txt_apply_im_subject'] = 				"group membership application";
$lang['txt_from_profile'] = 						"profile";

?>

==> aroundme_0_6_8.zip: aroundme_0_6_8/aroundme/language/1/barnraiser_01/grp_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HEADER
$lang['hdr_blocked'] = 							"blocked";
$lang['hdr_delete_membership'] = 				"delete membership";
$lang['hdr_delete_membership_confirm'] = 		"confirm";
$lang['hdr_member_library'] = 					"latest published wiki pages";
$lang['hdr_member_blogs'] = 					"latest published blogs";
$lang['hdr_member_subjects'] = 					"latest published subjects";
$lang['hdr_member_comments'] = 					"latest published comments";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_edit_membership'] = 					"edit membership";
$lang['hdr_profile'] =		 					"profile";
$lang['hdr_apply'] = 							"joining this group";
$lang['hdr_group_rules'] = 						"group rules";
$lang['hdr_node_rules'] = 						"node rules";

// SUBMIT
$lang['sub_confirm_delete'] =		 			"CONFIRM DELETION";
$lang['sub_join'] = 							"join";


//A HREF TAGS (links)
$lang['href_blocked_list'] = 					"see blocked user list";


//BODY TEXT
$lang['txt_delete_my_membership'] = 			"Do you want to delete your membership of this group? You can press 'delete' below to do so. You will be prompted to confirm your request.";
$lang['txt_delete_membership'] = 				"Do you want to delete this members membership from this group? You can press 'delete' below to do so. You will be prompted to confirm your request.";
$lang['txt_delete_membership_confirm'] = 		"Please confirm that you want to be deleted pressing 'confirm deletion'. Please note, the contributions you have made to this group will not be deleted.";
$lang['txt_member_profile'] = 					"member profile";
$lang['txt_blocked_help'] = 					"This person is blocked.";
$lang['txt_group_join_date'] = 					"group join date";
$lang['txt_membership_role'] = 					"type";
$lang['txt_profile_create_datetime'] = 			"joined";
$lang['txt_profile_hometown'] = 				"home town";
$lang['txt_profile_join_date'] = 				"community join date";
$lang['txt_profile_session_status'] = 			"status";
$lang['txt_profile_summary'] = 					"summary";
$lang['txt_member_role'] = 						"member role";
$lang['txt_member_status'] = 					"member status";
$lang['txt_membership_number'] = 				"number";
$lang['txt_profile'] = 							"profile";
$lang['txt_registration_type'] = 				"registration type";
$lang['txt_group_title'] =						"title";
$lang['txt_language'] = 						"language";
$lang['txt_start_date'] = 						"start date";
$lang['txt_status'] = 							"group status";
$lang['txt_group_age'] = 						"recommended age";
$lang['txt_group_registration_type'] = 			"registration type";
$lang['txt_no_access_allowed_login'] = 			"Please <a href='index.php'>login</a> or <a href='register.php'>register</a> to apply to join this group.";
$lang['txt_join_notes'] = 						"I agree to the rules";
$lang['txt_group_pending'] = 					"Your group application is pending. The group administrator will Instant message you with the results of your application.";
$lang['txt_group_automatic'] = 					"Welcome to this group. Press the button below to come on in.";
$lang['txt_group_approved'] = 					"Welcome to this group. Press the button below to join. The group administrator will contact you if your application is approved";
$lang['txt_group_unavailable'] = 				"Sorry, this group is unavailable at this time.";
$lang['txt_profile_select_txt'] = 				"select the profile you wish to use in this group";
$lang['txt_apply_im_subject'] = 				"group membership application";
$lang['txt_from_profile'] = 					"profile";

?>
